INSTAKIT
========

Instakit<sup><b>†</b></sup> is a suite of image processors and filters, for processing PIL images.

InstaKit processors use the same API as [PILKit](https://github.com/matthewwithanm/pilkit)'s,
so they can be used with anything that supports those, including [ImageKit](https://github.com/matthewwithanm/django-imagekit).
Or you can just use them by themselves to process images using Python.

As of this first draft there are [Instagrammy](http://www.instagram.com/) image-curve adjusters and a few other geegaws.

![one](http://i.imgur.com/pQ6Vw.jpg)

![two](http://i.imgur.com/ln1Eq.jpg)

![three](http://i.imgur.com/MBuC5.jpg)

Instakit is made available to you and the public at large under the [MIT license](http://opensource.org/licenses/MIT) -- see LICENSE.md for the full text.

 † née “django-instakit” – All dependencies and traces of Django have since been excised, with thanks to [matthewwithanm](https://github.com/matthewwithanm).
